@@ -5,6 +5,7 @@
 #include <unistd.h>
 #include <sched.h>
 #include <errno.h>
+#include <stdlib.h>
 
 static int child(void *arg) {
 	char **argv = (char **) arg;
@@ -15,8 +16,8 @@ static int child(void *arg) {
 }
 
 int main(int argc, char *argv[]) {
-	static char stack[8192];
-	const pid_t pid = clone(child, stack + (sizeof(stack) / 2), CLONE_NEWNS, (void *) argv);
+	char *stack = malloc(8192);
+	const pid_t pid = clone(child, stack + (8192 / 2), CLONE_NEWNS, (void *) argv);
 	while (waitpid(pid, NULL, __WALL) == EOF && errno == EINTR);
 	return 0;
 }
